pub fn create_draft_file(
kind: ComposeKind,
from: &str,
) -> Result<(PathBuf, usize), ComposeError>Expand description
Create a draft file on disk and return its path + the cursor line.
pub fn create_draft_file(
kind: ComposeKind,
from: &str,
) -> Result<(PathBuf, usize), ComposeError>Create a draft file on disk and return its path + the cursor line.